@@ -6,11 +6,11 @@
 use super::*;
 
 pub trait RoleRefExt: Sized {
-    fn new<T: kube::Resource<DynamicType = ()>>(name: impl ToString) -> Self;
+    fn new<T: kube::Resource<DynamicType = ()>, S: ToString>(name: S) -> Self;
 }
 
 impl RoleRefExt for rbacv1::RoleRef {
-    fn new<T: kube::Resource<DynamicType = ()>>(name: impl ToString) -> Self {
+    fn new<T: kube::Resource<DynamicType = ()>, S: ToString>(name: S) -> Self {
         let name = name.to_string();
         let api_group = T::group(&()).to_string();
         let kind = T::kind(&()).to_string();
