@@ -119,6 +119,26 @@ impl super::Kubectl {
         self.secrets(None).get(name).await
     }
 
+    pub async fn put_secret(
+        &self,
+        name: &str,
+        r#type: &str,
+        data: BTreeMap<String, ByteString>,
+    ) -> kube::Result<corev1::Secret> {
+        let secret: corev1::Secret = json::from_value(json::json!(
+            {
+                "metadata": {
+                    "name": name
+                },
+                "data": data,
+                "type": r#type
+            }
+        ))
+        .expect("Failed to create corev1::Secret");
+
+        self.ensure_default_namespaced_k_is_installed(secret).await
+    }
+
     pub async fn get_config_map(&self, name: &str) -> kube::Result<corev1::ConfigMap> {
         self.configmaps(None).get(name).await
     }
